@@ -5,8 +5,7 @@
 
 html_theme = 'insipid'
 
-# Set to empty string to disable links to sections
-html_add_permalinks = '\N{SECTION SIGN}'
+html_permalinks_icon = '\N{SECTION SIGN}'
 
 # -- Recommended settings for readthedocs.org ---------------------------------
 
@@ -108,8 +107,8 @@ html_secnumber_suffix = '\N{FIGURE SPACE}'
 # Generate domain indices, e.g. Python module index
 #html_domain_indices = False
 
-# This will be the default in Sphinx 4+
-#html_codeblock_linenos_style = 'inline'
+# The default in Sphinx 4+ is 'inline'
+#html_codeblock_linenos_style = 'table'
 
 # -- Sphinx extensions --------------------------------------------------------
 
